Crate jsonette

Crate jsonette 

Shell owns rendering only. All logic lives here.

Re-exports

pub use json_node::JsonNode;
pub use json_node::KeyValuePair;
pub use types::AppSettings;
pub use types::CompletionItem;
pub use types::Diagnostic;
pub use types::FoldingStyle;
pub use types::FormatOptions;
pub use types::LineEnding;
pub use types::LintOptions;
pub use types::ParserOptions;
pub use types::Severity;
pub use types::Span;
pub use completion::completions_at;
pub use formatter::format;
pub use formatter::minify;
pub use parser::diagnostics;
pub use parser::parse;
pub use parser::tolerant_parse;
pub use query::diagnostics_for_path;
pub use query::evaluate_path;
pub use settings::Settings;
pub use settings::get_settings;
pub use settings::set_in_memory_settings;
pub use settings::update_settings;

Modules

completion
JSONPath auto-completion and suggestion engine.
formatter
Pretty printing and minification for the JSON AST.
json_node
JsonNode types definition
parser
The parsing module contains the strict and tolerant JSON parsers, as well as fast diagnostics syntax checking and parsing helper utilities.
query
RFC 9535-conformant JSONPath expression evaluation and path diagnostics.
settings
Thread-safe global settings singleton and configuration cache manager.
types
Public API types definitions

Functions

ping
A trivial ping-pong function to verify the UniFFI FFI bridge is working end-to-end.