Module generator

Module generator 

Schema-based Dummy Data JSON Generator.

Evaluates a template JsonNode schema and generates a new JsonNode containing dummy data according to the schema rules.

Structs

GeneratorOptions
Options for the generation process.

Functions

generate_from_schema
Evaluates a schema and returns the generated dummy data. Returns a list of diagnostics if the schema contains structural errors.