pub struct GeneratorOptions {
pub target_size_bytes: Option<usize>,
pub target_count: Option<usize>,
}Expand description
Options for the generation process.
Fields
target_size_bytes: Option<usize>If provided, the generator will wrap the schema in an array and repeat it until the approximate byte size is reached.
target_count: Option<usize>If provided, the generator will wrap the schema in an array and repeat
it exactly target_count times.