Schema-based Dummy Data JSON Generator.
Evaluates a template JsonNode schema and generates a new JsonNode
containing dummy data according to the schema rules.
Structs
- Generator
Options - Options for the generation process.
Functions
- generate_
from_ schema - Evaluates a schema and returns the generated dummy data. Returns a list of diagnostics if the schema contains structural errors.