Module settings

Module settings 

Thread-safe global settings singleton and configuration cache manager.

Structs

Settings
Singleton manager for system settings matching the StarUML architecture model.

Functions

get_settings
Retrieves a copy of the current global configuration settings. Resolves preferences lazily from disk on the first invocation.
set_in_memory_settings
Updates the in-memory preferences without persisting them to disk.
update_settings
Updates the in-memory preferences and persists the changes to disk.